C guarding the apis

[ROCm/hip commit: 496da0aabd]
This commit is contained in:
Aditya Atluri
2016-03-30 06:08:50 -05:00
parent 3683e2a3bd
commit afd8f2bcfc
10 changed files with 64 additions and 97 deletions
+19
View File
@@ -0,0 +1,19 @@
#include<hip_runtime.h>
#include<hip_runtime_api.h>
__global__ void Kernel(hipLaunchParm lp, float *Ad){
int tx = hipThreadIdx_x + hipBlockIdx_x * hipBlockDim_x;
}
int main(){
dim3 dimBlock;
dim3 dimGrid;
dimGrid.x = 1;
dimGrid.y = 1;
dimGrid.z = 1;
dimBlock.x = 1;
dimBlock.y = 1;
dimBlock.z = 1;
float *A;
hipLaunchKernel(HIP_KERNEL_NAME(Kernel), dimGrid, dimBlock, 0, 0, A);
}